## v1.2.6 (2022-12-20)

### Fix

- Fixed small typing issue

## v1.2.5 (2022-12-03)

### Fix

- Fixed CI badge on readme

## v1.2.4 (2022-12-03)

### Fix

- Reorganized workflows

## v1.2.3 (2022-12-03)

### Fix

- I was re-checking out the repo

## v1.2.2 (2022-12-03)

### Fix

- Changed action for softprops/action-gh-release

## v1.2.1 (2022-12-03)

### Fix

- Added missing commitizen dep

## v1.2.0 (2022-12-03)

>>>>>>> d12f20d9790c04622957a14d2304e149b78d49df
### Feat

- Added CI autorelease
- Upgrading workflows
- Migrating to hatch
- :sparkles: Check correct aircrack version and root (#41)
- :sparkles: #29 Improved airmon-ng interface
- :sparkles: #37 Improved aireplay-ng usability (#38)
- Added debug mode. Don't delete tempfiles
- closes: #11 Added pypi to github flow

### Fix

- :bug: #29 Don't break on exit in most cases
- Added run-as-root message
- Fixed airmon test
- [#10] Using codecov badge
- [#10] Migrating to codecov
